#
# spec file for package bcachefs-tools
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           bcachefs-tools
Version:        1.20.0
Release:        1.1
Summary:        Configuration utilities for bcachefs
License:        GPL-2.0-or-later
Group:          System/Filesystems
URL:            https://bcachefs.org/
Source0:        https://evilpiepirate.org/%name/%name-vendored-%version.tar.zst
Source1:        https://evilpiepirate.org/%name/%name-vendored-%version.tar.sign
Source2:        %{name}.keyring
BuildRequires:  cargo
BuildRequires:  clang-devel
BuildRequires:  libaio-devel >= 0.3.111
BuildRequires:  pkg-config
BuildRequires:  zstd
BuildRequires:  pkgconfig(blkid)
BuildRequires:  pkgconfig(libkeyutils)
BuildRequires:  pkgconfig(liblz4)
BuildRequires:  pkgconfig(libsodium)
BuildRequires:  pkgconfig(libudev)
BuildRequires:  pkgconfig(liburcu)
BuildRequires:  pkgconfig(libzstd)
BuildRequires:  pkgconfig(udev)
BuildRequires:  pkgconfig(uuid)
BuildRequires:  pkgconfig(zlib)

%description
Bcachefs is a filesystem for Linux, with an emphasis on reliability
and robustness.

* Copy on write (COW) like zfs or btrfs
* Full data and metadata checksumming
* Multiple devices
* Replication
* Erasure coding
* Caching
* Compression
* Encryption
* Snapshots

This package contains utilities for creating and mounting bcachefs.

%prep
%autosetup -p1

%build
# The combination of -Og/-O1/-O2 + LTO produces a broken mkfs.bcachefs which
# crashes (disabling one of the two fixes it). Given this -O+LTO scenario, if
# -g2 is also used, the lto1-wpa process runs into memory exhaustion (>80GB)
# and the build fails altogether.
%define _lto_cflags %nil
# gh/koverstreet/bcachefs-tools#237
# bcachefs-tools uses malloc_usable_size, which is incompatible
# with fortification level 3
export CFLAGS="${RPM_OPT_FLAGS/_FORTIFY_SOURCE=3/_FORTIFY_SOURCE=2}"
export CXXFLAGS="$CFLAGS"
# Workaround antisocial Makefile that forces its own -O level
export EXTRA_CFLAGS="$CFLAGS"
%make_build PREFIX="%_prefix" ROOT_SBINDIR="%_sbindir"

%install
%make_install PREFIX="%_prefix" ROOT_SBINDIR="%_sbindir"
# this ain't no debian
rm -Rf "%buildroot/etc/initramfs-tools" "%buildroot/%_datadir/initramfs-tools"

%pre
%service_add_pre bcachefsck_all.service bcachefsck_all_fail.service

%post
%service_add_post bcachefsck_all.service bcachefsck_all_fail.service

%preun
%service_del_preun bcachefsck_all.service bcachefsck_all_fail.service

%postun
%service_del_postun bcachefsck_all.service bcachefsck_all_fail.service

%files
%_sbindir/*bcache*
%_unitdir/bcachefsck*
%_unitdir/system-bcachefsck*
%_libexecdir/bcachefsck*
%_udevrulesdir/64-bcachefs.rules
%_mandir/man8/*.8*
%license COPYING
%doc doc/bcachefs-principles-of-operation.tex

%changelog
* Thu Feb  6 2025 Petr Vorel <pvorel@suse.cz>
- Update to 1.20.0:
  * bcachefs fs top - show runtime performance information
  * various fixes
* Wed Dec 18 2024 Richard Rahl <rrahl0@opensuse.org>
- update to 1.13.0:
  * posix_to_bcachefs: fix missing copy_xattrs() error checking
  * Change lingering set-option texts to set-fs-option
  * change setattr to set-file-option in docs/usage
- update to 1.11.1:
  * bch_bindgen: Remove memoffset dep
  * cmd_list: open with noexcl
  * fuse: graceful shutdown when startup fails
* Sun Aug 18 2024 Jan Engelhardt <jengelh@inai.de>
- Update to release 1.11.0
  * mount: Fix UAF in option string handling
  * mount: Support asking for password via systemd-ask-password
- Fix a crash in mkfs.bcachefs by disabling LTO.
* Mon Jul 22 2024 David Disseldorp <ddiss@suse.de>
- Update to release v1.9.4
  * No longer logging by default
  * Fix undefined behavour
* Fri Jul 12 2024 David Disseldorp <ddiss@suse.de>
- Update to release v1.9.3
  * Fix 32-bit builds further
* Tue Jul  2 2024 David Disseldorp <ddiss@suse.de>
- Update to release v1.9.2
  * Fix fsck: Revert OPT_MOUNT change for read_only and make it OPT_HIDDEN
- Remove upstreamed patch
  * 0001-key-use-c_long-type-for-keyctl_search-helper-fn.patch
* Thu Jun 20 2024 David Disseldorp <ddiss@suse.de>
- Update to release v1.9.1
  * disk_accounting_v2: report on compression type/ratio, btree usage,
    and pending rebalance work.
- Fix 32-bit builds
  * add 0001-key-use-c_long-type-for-keyctl_search-helper-fn.patch
* Wed Jun 19 2024 Joshua Smith <smolsheep@opensuse.org>
- Update to release v1.9.1:
  * improve editorconfig to include sh scripts
  * fix: remove newlines from passphrase
  * fix: search for key in all keyrings
- Updates from release v1.9.0:
  * add BCACHEFS_BLOCK_SCAN environment variable for users that
  * add BCACHEFS_KERNEL_ONLY environment variable for test
    bcachefs, utilize it. Otherwise, resort to traversing block
    devices and checking for bcachefs super blocks.
    environments
  * Handle mount with FS with 1 device
    have a broken blkid which renders the udev db as incomplete
  * manpage: incorrect "delete" to "snapshot"
  * mount: If the udev database contains information about
  * mount: Make udev_bcachefs_info more idiomatic
  * fix typo that causes encrypted drives to become stuck in a
    busy loop
  * check_for_key before ask_for_passphrase -- check if there is
    already a key in the keyring available before trying to get the
    key from some more involved means
* Thu Apr 18 2024 David Disseldorp <ddiss@suse.de>
- Update to release v1.7.0
  * New on disk forat feature - per member 64-bit bitmap of regions
    with btree nodes, to accelerate recovering by scanning for
    btree nodes.
  * mount: canonicalize device path for single device node
  * Topology repair now uses nodes found by scanning to fill holes
  * mount: Handle multi-device with 1 device node
* Mon Mar  4 2024 David Disseldorp <ddiss@suse.de>
- Update to release v1.6.4
  * fix build on powerpc
  * drop upstream rust-use-libc-Ioctl-type-for-ioctl-request-argument.patch
* Thu Feb 22 2024 David Disseldorp <ddiss@suse.de>
- Fix 32-bit builds [boo#1220175]
  * add rust-use-libc-Ioctl-type-for-ioctl-request-argument.patch
* Wed Feb 21 2024 David Disseldorp <ddiss@suse.de>
- Update to release v1.6.3
  * use the kernel fsck implementation if the kernel version is a better
    match for the filesystem on disk than the -tools version
  * fix building with old gcc
  * fix big endian build
  * collect kernel fsck return code
  * various other fixes
* Mon Jan 29 2024 David Disseldorp <ddiss@suse.de>
- Build with rust functionality enabled [boo#1219158]
  * Switch to upstream vendored source tarball
  * Validate upstream source signature
* Sat Jan 27 2024 Jan Engelhardt <jengelh@inai.de>
- Rectify paths in systemd unit files [boo#1218808]
* Fri Jan 19 2024 Joshua Smith <jsmithfpv@gmail.com>
- Delete use_libexec_not_lib.patch (merged)
- Update to release v1.4.1
  * fix cmd_fsck, "bad mount option read-only"
  * now open block devices with O_EXCL
* Tue Jan  9 2024 Joshua Smith <jsmithfpv@gmail.com>
- Add use_libexec_not_lib.patch
- Update to v1.4.0:
  * bugfix release
  * Split brain detection
  * BCH_IOCTL_OFFLINE_FSCK, and numerous other features and
    bugfixes.
* Sun Dec  3 2023 Joshua Smith <jsmithfpv@gmail.com>
- Update to v1.3.5:
  * Update from latest kernel bcachefs sources, pulling in fixes
    for deleted_inodes btree in particular
  * cmd_version now works properly
  * fixes for cmd_format, pick the same bucket size for all devices
    for the sake of erasure coding
  * rebalance_work point release
  * Fix race in closure_sync()
  * Updated bcachefs sources because
    bcachefs_metadata_version_deleted_inodes
  * Snapshot depth, skiplist fields
  * Updated bcachefs sources because
    bcachefs_metadata_version_major_minor
  * Fix quotas + snapshots
  * Rip out code for storing backpointers in alloc keys
  * Fragmentation LRU
  * Rework LRU btree
* Tue May 30 2023 Jan Engelhardt <jengelh@inai.de>
- Initial package (version 24) for build.opensuse.org
